/*
 * Copyright (C) 2013 Nikolay Sivov
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#if 0
#pragma makedep install
#endif

[
    object,
    uuid(0997a571-126e-11d0-9f8a-00a0c9a0631e),
    pointer_default(unique)
]
interface IRowPositionChange : IUnknown
{
    [local]
    HRESULT OnRowPositionChange([in] DBREASON reason,
                                [in] DBEVENTPHASE phase,
                                [in] BOOL cant_deny);

    [call_as(OnRowPositionChange)]
    HRESULT RemoteOnRowPositionChange([in] DBREASON reason,
                                      [in] DBEVENTPHASE phase,
                                      [in] BOOL cant_deny,
                                      [out] IErrorInfo **errorinfo);
}
